# PXD010372 - Ovarian cancer proteome

- [article](https://www.sciencedirect.com/science/article/pii/S0092867418311668) - data taken directly from supplementary tables
- PRIDE project [PXD010372](https://www.ebi.ac.uk/pride/archive/projects/PXD010372) - for reference

## Proteome Profiling of Ovarian Cancer

- curated protein groups intensities on log2 scale are provided by the authors in an excel
  table [here](https://ars.els-cdn.com/content/image/1-s2.0-S0092867418311668-mmc2.xlsx)


## Clinical information

View origonal PDF file [here](https://ars.els-cdn.com/content/image/1-s2.0-S0092867418311668-mmc1.pdf)

- only provided as summary statistics in Supplementary Table S2 and S4
- Supplementary Table S1 contained some disease information, which was dumped in 
  `meta.csv`.
